@@ -1,9 +1,7 @@
-import os
 from flask import Flask, render_template
-import configparser
 from .digestion import DigestiveSystem
 
-app = Flask(__name__)
+app = Flask(__name__, static_url_path="", static_folder="static")
 de = DigestiveSystem()
 
 
@@ -36,7 +34,7 @@ def package_info(pkgmgr, pkg):
 
 @app.route("/package/<pkgmgr>/<pkg>/uninstall")
 def package_uninstall(pkgmgr, pkg):
-    pkginfo = de.puke_package(pkgmgr, pkg)
+    pkginfo = de.poop_package(pkgmgr, pkg)
     return render_template(
         "package.html", pkgmgr=pkgmgr, pkg=pkg, data=get_data(), pkginfo=pkginfo
     )
